"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const child_process_1 = require("child_process");
const path_1 = require("path");
function buildAngularCli(appName) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            // Check package is installed locally
            require.resolve('@angular/service-worker');
            const playgroundIndex = getAppIndex(appName);
            yield toggleServiceWorker(playgroundIndex);
            console.log('Building for production with sandboxes...');
            // Cannot build w/ AOT due to runtime compiler dependency
            child_process_1.exec(`ng build -a=${appName} --prod --aot=false`, (err, stdout, stderr) => {
                if (err)
                    throw err;
                console.log(stdout);
            });
        }
        catch (err) {
            console.error(chalk_1.default.red('Error: --build requires @angular/service-worker to be installed locally.'));
            console.log('https://github.com/angular/angular-cli/wiki/build#service-worker');
            process.exit(1);
        }
    });
}
exports.buildAngularCli = buildAngularCli;
function getAppIndex(appName) {
    // Assumes .angular-cli.json is at root
    const cliFile = path_1.join(process.cwd(), '.angular-cli.json').replace(/.json$/, '');
    const cliConfig = require(cliFile);
    return cliConfig.apps.findIndex(app => app.name === appName);
}
function toggleServiceWorker(appIndex) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            child_process_1.exec(`ng set apps.${appIndex}.serviceWorker=true`, (err, stdout, stderr) => {
                if (err)
                    reject(err);
                resolve(true);
            });
        });
    });
}
