"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const chalk_1 = require("chalk");
const path_1 = require("path");
const fs_1 = require("fs");
const error_reporter_1 = require("./error-reporter");
function configure(argv) {
    program
        .name('angular-playground')
        .option('-C, --config <path>', 'Configuration file', './angular-playground.json')
        .option('-S, --src <path>', 'Specify component source directory', './src/')
        .option('--no-watch', 'Disable sandboxes watch', false)
        .option('--no-serve', 'Disable cli serve', false)
        .option('--no-chunk', 'Don\'t chunk sandbox files individually', false)
        .option('--build', 'Build your sandboxes with service workers enabled. Requires @angular/service-worker', false)
        .option('--check-errors', '', false)
        .option('--random-scenario', '', false)
        .option('--timeout', '', 90)
        .option('--report-type', '', error_reporter_1.REPORT_TYPE.LOG)
        .option('--report-path', '')
        .option('--ng-cli-app <appName>', '@angular/cli appName')
        .option('--ng-cli-env <path>', 'Path to @angular/cli environment')
        .option('--ng-cli-port <n>', '@angular/cli serve port', 4201)
        .option('--ng-cli-cmd <path>', 'Path to @angular/cli executable', 'node_modules/@angular/cli/bin/ng')
        .option('--ng-cli-args <list>', 'Additional @angular/cli arguments');
    program.parse(argv);
    return applyConfigurationFile(program);
}
exports.configure = configure;
function applyConfigurationFile(program) {
    const playgroundConfig = loadConfig(program.config);
    // TODO: Missing value error reporting
    return {
        sourceRoot: playgroundConfig.sourceRoot || program.src,
        chunk: negate(playgroundConfig.noChunk) || program.chunk,
        watch: negate(playgroundConfig.noWatch) || program.watch,
        serve: negate(playgroundConfig.noServe) || program.serve,
        buildWithServiceWorkers: playgroundConfig.build || program.build,
        verifySandboxes: playgroundConfig.verifySandboxes || program.checkErrors,
        randomScenario: playgroundConfig.randomScenario || program.randomScenario,
        timeout: playgroundConfig.timeout || program.timeout,
        reportPath: playgroundConfig.reportPath || program.reportPath,
        reportType: playgroundConfig.reportType || program.reportType,
        angularAppName: playgroundConfig.angularCli.appName || program.ngCliApp,
        angularCliPath: playgroundConfig.angularCli.cmdPath || program.ngCliCmd,
        angularCliPort: playgroundConfig.angularCli.port || program.ngCliPort,
        angularCliEnv: playgroundConfig.angularCli.env || program.ngCliEnv,
        angularCliAdditionalArgs: playgroundConfig.angularCli.args || program.ngCliArgs
    };
}
exports.applyConfigurationFile = applyConfigurationFile;
function loadConfig(path) {
    const configPath = path_1.resolve(path);
    if (!fs_1.existsSync(configPath)) {
        throw new Error(chalk_1.default.red(`Failed to load config file ${configPath}`));
    }
    return require(configPath.replace(/.json$/, ''));
}
function negate(value) {
    if (value === undefined) {
        return value;
    }
    return !value;
}
